package com.vingroup.vinidpay_sdk;

import android.app.Activity;
import android.content.Intent;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

import com.vinid.paysdk.VinIDPayParams;
import com.vinid.paysdk.VinIDPaySdk;
import com.vinid.paysdk.utils.EnvironmentMode;
import com.vinid.paysdk.utils.VinIDPayConstants;

import static android.app.Activity.RESULT_OK;

public class VinidpaySdkDelegate implements PluginRegistry.ActivityResultListener {

    private final Activity activity;
    private MethodChannel.Result pendingResult;

    VinidpaySdkDelegate(Activity activity) {
        this.activity = activity;
    }

    void proceedPayment(MethodCall call, MethodChannel.Result result) {

        pendingResult = result;
        String id = call.argument("id");
        String sign = call.argument("sign");
        boolean sandboxMode = call.argument("sandboxMode");

        VinIDPayParams params = new VinIDPayParams.Builder()
                .setOrderId(id)
                .setSignature(sign)
                .build();


        if (sandboxMode) {
            new VinIDPaySdk.Builder()
                    .setVinIDPayParams(params)
                    .setEnvironmentMode(EnvironmentMode.DEV)
                    .build()
                    .startPaymentForResult(activity, VinIDPayConstants.REQUEST_CODE_VINIDPAY_PAY);
        } else {
            new VinIDPaySdk.Builder()
                    .setVinIDPayParams(params)
                    .build()
                    .startPaymentForResult(activity, VinIDPayConstants.REQUEST_CODE_VINIDPAY_PAY);
        }

    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {

        if (requestCode == VinIDPayConstants.REQUEST_CODE_VINIDPAY_PAY && resultCode == RESULT_OK) {

            String transactionStatus = data.getStringExtra(VinIDPayConstants.EXTRA_RETURN_TRANSACTION_STATUS);

            switch (transactionStatus) {
                case VinIDPayConstants.TRANSACTION_SUCCESS:
                    pendingResult.success("payment successful!");
                    break;
                case VinIDPayConstants.TRANSACTION_ABORT:
                    pendingResult.success("user aborted payment");
                    break;
                case VinIDPayConstants.TRANSACTION_FAIL:
                    int errorCode = data.getIntExtra(
                            VinIDPayConstants.EXTRA_RETURN_ERROR_CODE,
                            0
                    );
                    pendingResult.success("payment failed with error code: " + errorCode);
                    break;
                default:
                    pendingResult.success("unknow status");
                    break;
            }
        }
        return false;
    }

}